@@ -2,6 +2,7 @@
 from django.shortcuts import get_object_or_404, render_to_response
 from django.conf import settings
 from django.http import HttpResponse, HttpResponseBadRequest
+from django.core.files import File as FileWrapper
 from models import File
 from django.core.files.uploadedfile import UploadedFile
 
@@ -65,24 +66,28 @@ def multiuploader(request):
         #settings imports
         try:
             file_delete_url = settings.MULTI_FILE_DELETE_URL+'/'
-            file_url = settings.MULTI_IMAGE_URL+'/'+image.key_data+'/'
+            # file_url = settings.MULTI_IMAGE_URL+'/'+image.key_data+'/'
         except AttributeError:
             file_delete_url = 'multi_delete/'
-            file_url = 'multi_image/'+image.key_data+'/'
+            # file_url = 'multi_image/'+image.key_data+'/'
+
+        file_url = image.image.url;
 
         #generating json response array
         result = []
         context = {"name":filename, 
             "size":file_size, 
-            "url":file_url, 
+            "url":file_url,
+            "file_id": image.id,
             "delete_url":file_delete_url+str(image.pk)+'/', 
             "delete_type":"POST",
         }
         #getting thumbnail url using sorl-thumbnail
-        print image.is_image
         if image.is_image:
             im = get_thumbnail(image, "80x80", quality=50)
             context['thumbnail_url'] = im.url
+        else:
+            context['thumbnail_url'] = settings.FILE_IMAGE_URL
 
         result.append(context)
         response_data = simplejson.dumps(result)
